import React, { useState } from "react";
import { withStyles } from "@material-ui/core/styles";
import MuiExpansionPanel from "@material-ui/core/Accordion";
import MuiExpansionPanelSummary from "@material-ui/core/AccordionSummary";
import MuiExpansionPanelDetails from "@material-ui/core/AccordionActions";
import Typography from "@material-ui/core/Typography";
import ExpandMoreIcon from "@material-ui/icons/ExpandMore";
import SearchEPCompCurriculum from "./SearchEPCompCurriculum";
import SearchEPTiposRec from "./SearchEPTiposRec";
import SearchEPEtapasEns from "./SesrchEPEtapasEns";
import SearchEPIdiomas from "./SearchEPIdiomas";
import { TextField } from "@material-ui/core";
import Paper from '@material-ui/core/Paper';
import styled from 'styled-components';

import './ExpansionPanel.css'

const ExpansionPanel = withStyles({
  root: {
    border: "1px solid rgba(0, 0, 0, .125)",
    boxShadow: "none",
    '.MuiButtonBase-root': {
      paddingInline: "0 !important"
    },
    "&:not(:last-child)": {
      borderBottom: 0
    },
    "&:before": {
      display: "none"
    },
    "&$expanded": {
      margin: "auto"
    }
  },
  expanded: {}
})(MuiExpansionPanel);

const ExpansionPanelSummary = withStyles({
  root: {
    color: "#666",
    marginBottom: -1,
    minHeight: 56,
    backgroundColor: "#fff",


    "&$expanded": {
      minHeight: 56,
      backgroundColor: "#fff"
    }
  },
  content: {
    "&$expanded": {
      margin: "12px 0"
    }
  },
  expanded: {}
})(MuiExpansionPanelSummary);


const ExpansionPanelDetails = withStyles(theme => ({
  root: {
    // padding: theme.spacing(2)
  }
}))(MuiExpansionPanelDetails);

export default function SearchExpansionPanel(props) {
  const [keyWords, setKeyWords] = useState("");
  const [errorInKeyWord, setErrorInKeyWord] = useState({
    message: "",
    state: false
  })

  const onKeyPressed = (e) => {
    if (e.key === "Enter") {
      if (keyWords.length === 0) {
        setErrorInKeyWord({
          state: true,
          message: "Preencha o campo"
        })
      }
      else
        props.setTag(keyWords)
    }
  }

  const HandleChangeText = (e) => {
    if (errorInKeyWord.state)
      setErrorInKeyWord({
        state: false,
        message: ""
      })
    setKeyWords(e.target.value);
  }

  return (
    <MainPaper square elevation={4} contrast={props.contrast}>
      <link
        href="https://fonts.googleapis.com/css?family=Roboto:400,500&display=swap"
        rel="stylesheet"
      />
      <ExpansionPanel square>
        <ExpansionPanelSummary
          aria-controls="panel1d-content"
          id="panel1d-header"
          style={props.contrast === "" ? {} : { backgroundColor: "black" }}
        >
          <Typography
            style={props.contrast === "" ? {
              fontSize: "18px",
              textTransform: "uppercase",
              fontWeight: "500",
            } : {
                fontSize: "18px",
                textTransform: "uppercase",
                fontWeight: "500",
                color: "white"
              }}
          >
            Filtros
          </Typography>
        </ExpansionPanelSummary>
      </ExpansionPanel>

      <ExpansionPanel square>
        <ExpansionPanelSummary
          expandIcon={<ExpandMoreIcon style={props.contrast === "" ? {} : { color: "white" }} />}
          style={props.contrast === "" ? {} : { backgroundColor: "black" }}
          aria-controls="panel2d-content"
          id="panel2d-header"
        >
          <Typography style={props.contrast === "" ? {} : { color: "white" }}>Componentes Curriculares</Typography>
        </ExpansionPanelSummary>
        <ExpansionPanelDetails style={props.contrast === "" ? {} : { backgroundColor: "black" }}>
          <SearchEPCompCurriculum
            contrast={props.contrast}
            curriculumComponents={props.curriculumComponents}
            setCurriculum={props.setCurriculum}
          />
        </ExpansionPanelDetails>
      </ExpansionPanel>

      <ExpansionPanel square>
        <ExpansionPanelSummary
          style={props.contrast === "" ? {} : { backgroundColor: "black" }}
          expandIcon={<ExpandMoreIcon style={props.contrast === "" ? {} : { color: "white" }} />}
          aria-controls="panel3d-content"
          id="panel3d-header"
        >
          <Typography style={props.contrast === "" ? {} : { color: "white" }}>Tipos de Recurso</Typography>
        </ExpansionPanelSummary>
        <ExpansionPanelDetails style={props.contrast === "" ? {} : { backgroundColor: "black" }}>
          <SearchEPTiposRec
            contrast={props.contrast}
            typeOfResources={props.typeOfResources}
            setTypeRes={props.setTypeRes}
          />
        </ExpansionPanelDetails>
      </ExpansionPanel>

      <ExpansionPanel square>
        <ExpansionPanelSummary
          style={props.contrast === "" ? {} : { backgroundColor: "black" }}
          aria-controls="panel4d-content"
          expandIcon={<ExpandMoreIcon style={props.contrast === "" ? {} : { color: "white" }} />}
          id="panel4d-header"
        >
          <Typography style={props.contrast === "" ? {} : { color: "white" }}>Etapas de Ensino</Typography>
        </ExpansionPanelSummary>
        <ExpansionPanelDetails style={props.contrast === "" ? {} : { backgroundColor: "black" }}>
          <SearchEPEtapasEns
            contrast={props.contrast}
            teachingStage={props.teachingStage}
            setTeachingStage={props.setTeachingStage}
          />
        </ExpansionPanelDetails>
      </ExpansionPanel>

      <ExpansionPanel square>
        <ExpansionPanelSummary
          style={props.contrast === "" ? {} : { backgroundColor: "black" }}
          aria-controls="panel5d-content"
          expandIcon={<ExpandMoreIcon style={props.contrast === "" ? {} : { color: "white" }} />}
          id="panel5d-header"
        >
          <Typography style={props.contrast === "" ? {} : { color: "white" }}>Idiomas</Typography>
        </ExpansionPanelSummary>
        <ExpansionPanelDetails style={props.contrast === "" ? {} : { backgroundColor: "black" }}>
          <SearchEPIdiomas
            contrast={props.contrast}
            languages={props.languages}
            setLanguages={props.setLanguages}
          />
        </ExpansionPanelDetails>
      </ExpansionPanel>

      <ExpansionPanel square>
        <ExpansionPanelSummary
          style={props.contrast === "" ? {} : { backgroundColor: "black", borderBottom: "1px solid white" }}
          aria-controls="panel6d-content"
          expandIcon={<ExpandMoreIcon style={props.contrast === "" ? {} : { color: "white" }} />}
          id="panel6d-header"
        >
          <Typography style={props.contrast === "" ? {} : { color: "white" }}>Palavra-Chave</Typography>
        </ExpansionPanelSummary>
        <ExpansionPanelDetails style={props.contrast === "" ? {} : { backgroundColor: "black" }}>
          <TextField
            label="Palavra chave + enter  "
            id="outlined-margin-dense"
            variant="outlined"
            onChange={e => HandleChangeText(e)}
            onKeyDown={e => onKeyPressed(e)}
            error={errorInKeyWord.state}
            helperText={errorInKeyWord.state ? errorInKeyWord.message : ""}
          />
        </ExpansionPanelDetails>
      </ExpansionPanel>
    </MainPaper>
  );
}

const MainPaper = styled(Paper)`
  text-align: center;
  margin-top: 5px;
  margin-bottom: 30px;
  color: #666;

  .textInfo{
    text-align: start;
  }
`;
